# Concatenate a series of path elements into a full URL path
#
# This method concatenates all tokens given as arguments into a single URL path,
# joining every element with `separator` ("/" by default), removing any duplicate
# separators introduces this way and ensuring that the final path starts with a
# separator.
#
# @param paths [String] Series of path elements to join
# @param separator [String] The string to use for joining path elements
# @return [String] The concatenated URL path
def join_url_paths(*paths, separator: '/')
    result = separator
    paths.each do |path|
        while path.start_with?(separator) do
            path.delete_prefix!(separator)
        end
        while path.end_with?(separator) do
            path.delete_suffix!(separator)
        end
        if ! path.empty?
            result += path + separator
        end
    end
    result
end
